@@ -57,13 +57,44 @@ ALL_ROUTES = [
     ('dns:zone-print', 'SoftLayer.CLI.dns.zone_print:cli'),
 
     ('block', 'SoftLayer.CLI.block'),
-    ('block:volume-list', 'SoftLayer.CLI.block.list:cli'),
-    ('block:volume-detail', 'SoftLayer.CLI.block.detail:cli'),
+    ('block:access-authorize', 'SoftLayer.CLI.block.access.authorize:cli'),
+    ('block:access-list', 'SoftLayer.CLI.block.access.list:cli'),
+    ('block:access-revoke', 'SoftLayer.CLI.block.access.revoke:cli'),
+    ('block:replica-failback', 'SoftLayer.CLI.block.replication.failback:cli'),
+    ('block:replica-failover', 'SoftLayer.CLI.block.replication.failover:cli'),
+    ('block:replica-order', 'SoftLayer.CLI.block.replication.order:cli'),
+    ('block:snapshot-cancel', 'SoftLayer.CLI.block.snapshot.cancel:cli'),
+    ('block:snapshot-create', 'SoftLayer.CLI.block.snapshot.create:cli'),
+    ('block:snapshot-delete', 'SoftLayer.CLI.block.snapshot.delete:cli'),
+    ('block:snapshot-disable', 'SoftLayer.CLI.block.snapshot.disable:cli'),
+    ('block:snapshot-enable', 'SoftLayer.CLI.block.snapshot.enable:cli'),
+    ('block:snapshot-list', 'SoftLayer.CLI.block.snapshot.list:cli'),
+    ('block:snapshot-order', 'SoftLayer.CLI.block.snapshot.order:cli'),
+    ('block:snapshot-restore', 'SoftLayer.CLI.block.snapshot.restore:cli'),
     ('block:volume-cancel', 'SoftLayer.CLI.block.cancel:cli'),
+    ('block:volume-detail', 'SoftLayer.CLI.block.detail:cli'),
+    ('block:volume-list', 'SoftLayer.CLI.block.list:cli'),
     ('block:volume-order', 'SoftLayer.CLI.block.order:cli'),
-    ('block:snapshot-list', 'SoftLayer.CLI.block.snapshot_list:cli'),
-    ('block:snapshot-delete', 'SoftLayer.CLI.block.snapshot_delete:cli'),
-    ('block:access-list', 'SoftLayer.CLI.block.access_list:cli'),
+
+    ('file', 'SoftLayer.CLI.file'),
+    ('file:access-authorize', 'SoftLayer.CLI.file.access.authorize:cli'),
+    ('file:access-list', 'SoftLayer.CLI.file.access.list:cli'),
+    ('file:access-revoke', 'SoftLayer.CLI.file.access.revoke:cli'),
+    ('file:replica-failback', 'SoftLayer.CLI.file.replication.failback:cli'),
+    ('file:replica-failover', 'SoftLayer.CLI.file.replication.failover:cli'),
+    ('file:replica-order', 'SoftLayer.CLI.file.replication.order:cli'),
+    ('file:snapshot-cancel', 'SoftLayer.CLI.file.snapshot.cancel:cli'),
+    ('file:snapshot-create', 'SoftLayer.CLI.file.snapshot.create:cli'),
+    ('file:snapshot-delete', 'SoftLayer.CLI.file.snapshot.delete:cli'),
+    ('file:snapshot-disable', 'SoftLayer.CLI.file.snapshot.disable:cli'),
+    ('file:snapshot-enable', 'SoftLayer.CLI.file.snapshot.enable:cli'),
+    ('file:snapshot-list', 'SoftLayer.CLI.file.snapshot.list:cli'),
+    ('file:snapshot-order', 'SoftLayer.CLI.file.snapshot.order:cli'),
+    ('file:snapshot-restore', 'SoftLayer.CLI.file.snapshot.restore:cli'),
+    ('file:volume-cancel', 'SoftLayer.CLI.file.cancel:cli'),
+    ('file:volume-detail', 'SoftLayer.CLI.file.detail:cli'),
+    ('file:volume-list', 'SoftLayer.CLI.file.list:cli'),
+    ('file:volume-order', 'SoftLayer.CLI.file.order:cli'),
 
     ('firewall', 'SoftLayer.CLI.firewall'),
     ('firewall:add', 'SoftLayer.CLI.firewall.add:cli'),
@@ -195,6 +226,7 @@ ALL_ROUTES = [
     ('ticket:detail', 'SoftLayer.CLI.ticket.detail:cli'),
     ('ticket:list', 'SoftLayer.CLI.ticket.list:cli'),
     ('ticket:update', 'SoftLayer.CLI.ticket.update:cli'),
+    ('ticket:upload', 'SoftLayer.CLI.ticket.upload:cli'),
     ('ticket:subjects', 'SoftLayer.CLI.ticket.subjects:cli'),
     ('ticket:summary', 'SoftLayer.CLI.ticket.summary:cli'),
     ('ticket:attach', 'SoftLayer.CLI.ticket.attach:cli'),
@@ -205,6 +237,9 @@ ALL_ROUTES = [
     ('vlan:list', 'SoftLayer.CLI.vlan.list:cli'),
 
     ('summary', 'SoftLayer.CLI.summary:cli'),
+
+    ('report', 'SoftLayer.CLI.report'),
+    ('report:bandwidth', 'SoftLayer.CLI.report.bandwidth:cli'),
 ]
 
 ALL_ALIASES = {
