@@ -49,12 +49,7 @@ def cli(env, identifier, passwords=False, price=False):
                                     'operatingSystem',
                                     'softwareLicense',
                                     'softwareDescription') or {}
-    table.add_row([
-        'os',
-        formatting.FormattedItem(
-            operating_system.get('version') or formatting.blank(),
-            operating_system.get('name') or formatting.blank()
-        )])
+    table.add_row(['os', operating_system.get('name') or formatting.blank()])
     table.add_row(['os_version',
                    operating_system.get('version') or formatting.blank()])
     table.add_row(['cores', result['maxCpu']])
@@ -86,8 +81,15 @@ def cli(env, identifier, passwords=False, price=False):
         table.add_row(['notes', result['notes']])
 
     if price:
-        table.add_row(['price rate',
-                       result['billingItem']['recurringFee']])
+        total_price = utils.lookup(result,
+                                   'billingItem',
+                                   'nextInvoiceTotalRecurringAmount') or 0
+        total_price += sum(p['nextInvoiceTotalRecurringAmount']
+                           for p
+                           in utils.lookup(result,
+                                           'billingItem',
+                                           'children') or [])
+        table.add_row(['price_rate', total_price])
 
     if passwords:
         pass_table = formatting.Table(['software', 'username', 'password'])
