@@ -1,17 +1,21 @@
 """Check if a virtual server is ready."""
 # :license: MIT, see LICENSE for more details.
 
+import click
+
 import SoftLayer
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import exceptions
 from SoftLayer.CLI import helpers
 
-import click
-
 
 @click.command()
 @click.argument('identifier')
-@click.option('--wait', default=0, type=click.INT, help="Name of the image")
+@click.option('--wait',
+              default=0,
+              show_default=True,
+              type=click.INT,
+              help="Name of the image")
 @environment.pass_env
 def cli(env, identifier, wait):
     """Check if a virtual server is ready."""
