@@ -41,8 +41,9 @@ class ServerCLITests(testing.TestCase):
             'memory': 2048,
             'notes': 'These are test notes.',
             'os': 'Ubuntu',
+            'os_version': 'Ubuntu 12.04 LTS',
             'owner': 'chechu',
-            'price rate': 16.08,
+            'price_rate': 21.08,
             'private_ip': '10.1.0.2',
             'ptr': '2.0.1.10.in-addr.arpa',
             'public_ip': '172.16.1.100',
@@ -55,7 +56,7 @@ class ServerCLITests(testing.TestCase):
         }
 
         self.assert_no_fail(result)
-        self.assertEqual(json.loads(result.output), expected)
+        self.assertEqual(expected, json.loads(result.output))
 
     def test_detail_vs_empty_tag(self):
         mock = self.set_mock('SoftLayer_Hardware_Server', 'getObject')
